gentoo/audit-2.6.4.ebuild at d8bae05997012bacefdf65cb1f273a437c448129 - gentoo - Gitea: Git with a cup of tea
Description: gentoo - my private gentoo overlay
Keywords: go,git,self-hosted,gitea

Dessa
/
gentoo
1
0
Fork
You've already forked gentoo
0
gentoo/sys-process/audit/audit-2.6.4.ebuild

####
228 lines
5.9 KiB
Bash
Raw Blame History

| `# Copyright 1999-2016 Gentoo Foundation`
| `# Distributed under the terms of the GNU General Public License v2`
| `# $Id$`
| ``
| `EAPI="6"`
| ``
| `PYTHON_COMPAT=( python{2_7,3_3,3_4,3_5} )`
| ``
| `inherit autotools multilib multilib-minimal toolchain-funcs python-r1 linux-info systemd`
| ``
| `DESCRIPTION="Userspace utilities for storing and processing auditing records"`
| `HOMEPAGE="https://people.redhat.com/sgrubb/audit/"`
| `SRC_URI="https://people.redhat.com/sgrubb/audit/${P}.tar.gz"`
| ``
| `LICENSE="GPL-2"`
| `SLOT="0"`
| `KEYWORDS="~alpha ~amd64 ~arm ~arm64 ~hppa ~ia64 ~mips ~ppc ~ppc64 ~s390 ~sh ~sparc ~x86"`
| `IUSE="apparmor ldap python tcpd"`
| `# Testcases are pretty useless as they are built for RedHat users/groups and kernels.`
| `RESTRICT="test"`
| ``
| `RDEPEND="apparmor? ( sys-apps/apparmor )`
| `ldap? ( net-nds/openldap )`
| `tcpd? ( sys-apps/tcp-wrappers )`
| `sys-libs/libcap-ng"`
| `DEPEND="${RDEPEND}`
| `>=sys-kernel/linux-headers-2.6.34`
| `python? (`
| `${PYTHON_DEPS}`
| `dev-lang/swig:0`
| `)"`
| `# Do not use os-headers as this is linux specific`
| ``
| `REQUIRED_USE="python? ( ${PYTHON_REQUIRED_USE} )"`
| ``
| `CONFIG_CHECK="~AUDIT"`
| ``
| `pkg_setup() {`
| `linux-info_pkg_setup`
| `}`
| ``
| `src_prepare() {`
| `eapply_user`
| ``
| `# Do not build GUI tools`
| `sed -i \`
| `-e '/AC_CONFIG_SUBDIRS.*system-config-audit/d' \`
| `"${S}"/configure.ac || die`
| `sed -i \`
| `-e 's,system-config-audit,,g' \`
| `"${S}"/Makefile.am || die`
| `rm -rf "${S}"/system-config-audit`
| ``
| `if ! use ldap; then`
| `sed -i \`
| `-e '/^AC_OUTPUT/s,audisp/plugins/zos-remote/Makefile,,g' \`
| `"${S}"/configure.ac || die`
| `sed -i \`
| `-e '/^SUBDIRS/s,zos-remote,,g' \`
| `"${S}"/audisp/plugins/Makefile.am || die`
| `fi`
| ``
| `# Don't build static version of Python module.`
| `eapply "${FILESDIR}"/${PN}-2.4.3-python.patch`
| ``
| `# glibc/kernel upstreams suck with both defining ia64_fpreg`
| `# This patch is a horribly workaround that is only valid as long as you`
| `# don't need the OTHER definitions in fpu.h.`
| `eapply "${FILESDIR}"/${PN}-2.1.3-ia64-compile-fix.patch`
| ``
| `# there is no --without-golang conf option`
| `sed -e "/^SUBDIRS =/s/ @gobind_dir@//" -i bindings/Makefile.am || die`
| ``
| `# Regenerate autotooling`
| `eautoreconf`
| `}`
| ``
| `multilib_src_configure() {`
| `local ECONF_SOURCE=${S}`
| `econf \`
| `--sbindir=/sbin \`
| `--enable-systemd \`
| `--without-python \`
| `--without-python3 \`
| `$(use_with apparmor) \`
| `$(multilib_native_use_with tcpd libwrap)`
| ``
| `if multilib_is_native_abi; then`
| `python_configure() {`
| `mkdir -p "${BUILD_DIR}" || die`
| `cd "${BUILD_DIR}" || die`
| ``
| `if python_is_python3; then`
| `econf --without-python --with-python3`
| `else`
| `econf --with-python --without-python3`
| `fi`
| `}`
| ``
| `use python && python_foreach_impl python_configure`
| `fi`
| `}`
| ``
| `multilib_src_compile() {`
| `if multilib_is_native_abi; then`
| `default`
| ``
| `python_compile() {`
| `local pysuffix pydef`
| `if python_is_python3; then`
| `pysuffix=3`
| `pydef='USE_PYTHON3=true'`
| `else`
| `pysuffix=2`
| `pydef='HAVE_PYTHON=true'`
| `fi`
| ``
| `emake -C "${BUILD_DIR}"/bindings/swig \`
| `VPATH="${native_build}/lib" \`
| `LIBS="${native_build}/lib/libaudit.la" \`
| `_audit_la_LIBADD="${native_build}/lib/libaudit.la" \`
| `_audit_la_DEPENDENCIES="${S}/lib/libaudit.h ${native_build}/lib/libaudit.la" \`
| `${pydef}`
| `emake -C "${BUILD_DIR}"/bindings/python/python${pysuffix} \`
| `VPATH="${S}/bindings/python/python${pysuffix}:${native_build}/bindings/python/python${pysuffix}" \`
| `auparse_la_LIBADD="${native_build}/auparse/libauparse.la ${native_build}/lib/libaudit.la" \`
| `${pydef}`
| `}`
| ``
| `local native_build="${BUILD_DIR}"`
| `use python && python_foreach_impl python_compile`
| `else`
| `emake -C lib`
| `emake -C auparse`
| `fi`
| `}`
| ``
| `multilib_src_install() {`
| `if multilib_is_native_abi; then`
| `emake DESTDIR="${D}" initdir="$(systemd_get_systemunitdir)" install`
| ``
| `python_install() {`
| `local pysuffix pydef`
| `if python_is_python3; then`
| `pysuffix=3`
| `pydef='USE_PYTHON3=true'`
| `else`
| `pysuffix=2`
| `pydef='HAVE_PYTHON=true'`
| `fi`
| ``
| `emake -C "${BUILD_DIR}"/bindings/swig \`
| `VPATH="${native_build}/lib" \`
| `LIBS="${native_build}/lib/libaudit.la" \`
| `_audit_la_LIBADD="${native_build}/lib/libaudit.la" \`
| `_audit_la_DEPENDENCIES="${S}/lib/libaudit.h ${native_build}/lib/libaudit.la" \`
| `${pydef} \`
| `DESTDIR="${D}" install`
| `emake -C "${BUILD_DIR}"/bindings/python/python${pysuffix} \`
| `VPATH="${S}/bindings/python/python${pysuffix}:${native_build}/bindings/python/python${pysuffix}" \`
| `auparse_la_LIBADD="${native_build}/auparse/libauparse.la ${native_build}/lib/libaudit.la" \`
| `${pydef} \`
| `DESTDIR="${D}" install`
| `}`
| ``
| `local native_build=${BUILD_DIR}`
| `use python && python_foreach_impl python_install`
| ``
| `# things like shadow use this so we need to be in /`
| `gen_usr_ldscript -a audit auparse`
| `else`
| `emake -C lib DESTDIR="${D}" install`
| `emake -C auparse DESTDIR="${D}" install`
| `fi`
| `}`
| ``
| `multilib_src_install_all() {`
| `dodoc AUTHORS ChangeLog README* THANKS TODO`
| `docinto contrib`
| `dodoc contrib/{avc_snap,skeleton.c}`
| `docinto contrib/plugin`
| `dodoc contrib/plugin/*`
| `docinto rules`
| `dodoc rules/*`
| ``
| `newinitd "${FILESDIR}"/auditd-init.d-2.4.3 auditd`
| `newconfd "${FILESDIR}"/auditd-conf.d-2.1.3 auditd`
| ``
| `fperms 644 "$(systemd_get_systemunitdir)"/auditd.service # 556436`
| ``
| `[ -f "${D}"/sbin/audisp-remote ] && \`
| `dodir /usr/sbin && \`
| `mv "${D}"/{sbin,usr/sbin}/audisp-remote || die`
| ``
| `# Gentoo rules`
| `insinto /etc/audit/`
| `newins "${FILESDIR}"/audit.rules-2.1.3 audit.rules`
| `doins "${FILESDIR}"/audit.rules.stop*`
| ``
| `# audit logs go here`
| `keepdir /var/log/audit/`
| ``
| `# Security`
| `lockdown_perms "${D}"`
| ``
| `prune_libtool_files --modules`
| `}`
| ``
| `pkg_preinst() {`
| `# Preserve from the audit-1 series`
| `preserve_old_lib /$(get_libdir)/libaudit.so.0`
| `}`
| ``
| `pkg_postinst() {`
| `lockdown_perms "${ROOT}"`
| `# Preserve from the audit-1 series`
| `preserve_old_lib_notify /$(get_libdir)/libaudit.so.0`
| `}`
| ``
| `lockdown_perms() {`
| `# upstream wants these to have restrictive perms`
| `# should not || die, maybe not all paths exist`
| `basedir="$1"`
| `chmod 0750 "${basedir}"/sbin/au{ditctl,report,dispd,ditd,search,trace} 2>/dev/null`
| `chmod 0750 "${basedir}"/var/log/audit/ 2>/dev/null`
| `chmod 0640 "${basedir}"/etc/{audit/,}{auditd.conf,audit.rules*} 2>/dev/null`
| `}`